<?php

use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/

// Главная страница
Route::view('/', 'index');

use App\Http\Controllers;
use App\Http\Resources;
use App\Models;

// Книги
Route::get('/books', [Controllers\BookController::class, 'index']);
Route::get('/book/add', [Controllers\BookController::class, 'add']);
Route::get('/book/{book}', [Controllers\BookController::class, 'view']);
Route::get('/book/{book}/delete', [Controllers\BookController::class, 'drop']);
Route::get('/book/{book}/edit', [Controllers\BookController::class, 'edit']);
Route::post('/book/{book}/edit', [Controllers\BookController::class, 'store']);
Route::post('/book/{book}/comment', [Controllers\BookController::class, 'comment']);
Route::post('/book/add', [Controllers\BookController::class, 'store']);

// Авторы
Route::get('/authors', [Controllers\AuthorController::class, 'index']);
Route::get('/author/add', [Controllers\AuthorController::class, 'add']);
Route::get('/author/{author}', [Controllers\AuthorController::class, 'view']);
Route::get('/author/{author}/delete', [Controllers\AuthorController::class, 'drop']);
Route::get('/author/{author}/edit', [Controllers\AuthorController::class, 'edit']);
Route::post('/author/{author}/edit', [Controllers\AuthorController::class, 'store']);
Route::post('/author/{author}/comment', [Controllers\AuthorController::class, 'comment']);
Route::post('/author/add', [Controllers\AuthorController::class, 'store']);

// API
Route::get('/api/authors', function() { return Resources\AuthorResource::collection(Models\Author::all()); });
Route::get('/api/books', function() { return Resources\BookResource::collection(Models\Book::all()->load("author")); });

// Публикации
Route::get('/articles', [Controllers\ArticleController::class, 'index']);
Route::get('/article/add', [Controllers\ArticleController::class, 'add']);
Route::get('/article/{article}', [Controllers\ArticleController::class, 'view']);
Route::get('/article/{article}/delete', [Controllers\ArticleController::class, 'drop']);
Route::get('/article/{article}/edit', [Controllers\ArticleController::class, 'edit']);
Route::post('/article/{article}/edit', [Controllers\ArticleController::class, 'store']);
Route::post('/article/add', [Controllers\ArticleController::class, 'store']);
